@@ -181,7 +181,7 @@ class ChatCompletionRequest(BaseModel):
     safe_mode: Optional[bool] = Field(default=False)
     preserve_model_alias: Optional[bool] = False
     fallback_config: Optional[config.FallbackConfig] = None
-    request_type: Literal["PROD", "RERUN", "SYNTHETIC"] = "PROD"
+    request_type: Literal["PROD", "RERUN", "SYNTHETIC", "MANUAL"] = "PROD"
 
 
 class FunctionCall(BaseModel):
