@@ -23,6 +23,8 @@ class KeyIdMap(BaseModel):
     cerebras_api_key: Optional[int] = 0
     azure_api_key: Optional[int] = 0
     sambanova_api_key: Optional[int] = 0
+    gemini_api_key: Optional[int] = 0
+    deepseek_api_key: Optional[int] = 0
 
 
 class KeyMap(BaseModel):
@@ -32,6 +34,8 @@ class KeyMap(BaseModel):
     cerebras_api_key: Optional[Key] = None
     azure_api_key: Optional[Key] = None
     sambanova_api_key: Optional[Key] = None
+    gemini_api_key: Optional[Key] = None
+    deepseek_api_key: Optional[Key] = None
 
 
 Key.model_rebuild()
