@@ -3,8 +3,7 @@ import json
 import re
 from typing import get_type_hints
 
-from maitai._types import ToolFunction
-from maitai_gen.chat import Function, Tool, ToolCall
+from maitai.models.chat import Function, FunctionParameters, Property, Tool, ToolCall
 
 
 class Tools:
@@ -12,7 +11,7 @@ class Tools:
         self.available_functions = {}
         self.definitions = []
         for func in tools:
-            if not isinstance(func, ToolFunction):
+            if not hasattr(func, "__tool__"):
                 raise TypeError(f"Method passed into tools missing @tool decorator")
             tool_call = func.__tool__
             self.available_functions[tool_call.function.name] = func
@@ -21,17 +20,29 @@ class Tools:
     def get_tool_definitions(self):
         return self.definitions
 
-    def invoke(self, tool_call: ToolCall):
+    def invoke(self, tool_call: ToolCall, **override_args):
+        if tool_call.function.name not in self.available_functions:
+            raise TypeError(f"Function {tool_call.function.name} is not defined")
         function_to_call = self.available_functions[tool_call.function.name]
-        function_args = json.loads(tool_call.function.arguments)
+        try:
+            function_args = json.loads(tool_call.function.arguments)
+        except json.JSONDecodeError:
+            function_args = {}
+        function_args.update(override_args)
         function_response = function_to_call(**function_args)
         return function_response
 
 
-def tool(func):
+def tool(func=None, strict=False):
+    if func is None:
+        return lambda f: tool(f, strict=strict)
+
     function_description = func.__doc__
     if not function_description:
         raise ValueError("Missing docstring for tool")
+    function_description = (
+        function_description.split(":param")[0].split("Args:")[0].strip()
+    )
 
     def wrapper(*args, **kwargs):
         return func(*args, **kwargs)
@@ -45,30 +56,32 @@ def tool(func):
 
     param_descriptions = _extract_param_details(func.__doc__)
     for param_name, param in params.items():
+        if param_name in ["self", "cls"]:
+            continue
         if param_name in type_hints:
             param_type = type_hints[param_name].__name__
         elif param.default is not param.empty and param.default is not None:
             param_type = type(param.default).__name__
         else:
             param_type = "string"
-        properties[param_name] = {
-            "type": _parse_type(param_type),
-            "description": param_descriptions.get(param_name, ""),
-        }
-        if param.default is param.empty:
-            required.append(param_name)
+        properties[param_name] = Property(
+            type=_parse_type(param_type),
+            description=param_descriptions.get(param_name, ""),
+        )
+        required.append(param_name)
 
     wrapper.__tool__ = Tool(
         type="function",
         function=Function(
             name=func.__name__,
+            strict=strict,
             description=function_description,
-            parameters={
-                "type": "object",
-                "properties": properties,
-                "required": required,
-            },
-        )
+            parameters=FunctionParameters(
+                type="object",
+                properties=properties,
+                required=required,
+            ),
+        ),
     )
     return wrapper
 
